#include <libint2.h>

#ifdef __cplusplus
extern "C" {
#endif
void OSVRRP0InBra_aB_h__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(const Libint_t* inteval, LIBINT2_REALTYPE* target, const LIBINT2_REALTYPE* src0, const LIBINT2_REALTYPE* src1, const LIBINT2_REALTYPE* src2, const LIBINT2_REALTYPE* src3, const LIBINT2_REALTYPE* src4) {

LIBINT2_REALTYPE*const  stack = target;
{
const int hsi = 0;
{
const int lsi = 0;
{
const int vi = 0;
LIBINT2_REALTYPE fp233;
fp233 = inteval->oo2ze[vi] * src4[((hsi*15+6)*1+lsi)*1];
LIBINT2_REALTYPE fp237;
fp237 = inteval->roz[vi] * src3[((hsi*30+10)*1+lsi)*1];
LIBINT2_REALTYPE fp236;
fp236 = src2[((hsi*30+10)*1+lsi)*1] - fp237;
LIBINT2_REALTYPE fp238;
fp238 = 3 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp235;
fp235 = fp238 * fp236;
LIBINT2_REALTYPE fp240;
fp240 = inteval->WP_y[vi] * src1[((hsi*45+19)*1+lsi)*1];
LIBINT2_REALTYPE fp241;
fp241 = inteval->PA_y[vi] * src0[((hsi*45+19)*1+lsi)*1];
LIBINT2_REALTYPE fp239;
fp239 = fp241 + fp240;
LIBINT2_REALTYPE fp234;
fp234 = fp239 + fp235;
LIBINT2_REALTYPE fp232;
fp232 = fp234 + fp233;
target[((hsi*63+31)*1+lsi)*1] = fp232;
LIBINT2_REALTYPE fp245;
fp245 = inteval->roz[vi] * src3[((hsi*30+9)*1+lsi)*1];
LIBINT2_REALTYPE fp244;
fp244 = src2[((hsi*30+9)*1+lsi)*1] - fp245;
LIBINT2_REALTYPE fp246;
fp246 = 3 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp243;
fp243 = fp246 * fp244;
LIBINT2_REALTYPE fp248;
fp248 = inteval->WP_y[vi] * src1[((hsi*45+18)*1+lsi)*1];
LIBINT2_REALTYPE fp249;
fp249 = inteval->PA_y[vi] * src0[((hsi*45+18)*1+lsi)*1];
LIBINT2_REALTYPE fp247;
fp247 = fp249 + fp248;
LIBINT2_REALTYPE fp242;
fp242 = fp247 + fp243;
target[((hsi*63+30)*1+lsi)*1] = fp242;
LIBINT2_REALTYPE fp251;
fp251 = inteval->oo2ze[vi] * src4[((hsi*15+5)*1+lsi)*1];
LIBINT2_REALTYPE fp255;
fp255 = inteval->roz[vi] * src3[((hsi*30+8)*1+lsi)*1];
LIBINT2_REALTYPE fp254;
fp254 = src2[((hsi*30+8)*1+lsi)*1] - fp255;
LIBINT2_REALTYPE fp256;
fp256 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp253;
fp253 = fp256 * fp254;
LIBINT2_REALTYPE fp258;
fp258 = inteval->WP_z[vi] * src1[((hsi*45+17)*1+lsi)*1];
LIBINT2_REALTYPE fp259;
fp259 = inteval->PA_z[vi] * src0[((hsi*45+17)*1+lsi)*1];
LIBINT2_REALTYPE fp257;
fp257 = fp259 + fp258;
LIBINT2_REALTYPE fp252;
fp252 = fp257 + fp253;
LIBINT2_REALTYPE fp250;
fp250 = fp252 + fp251;
target[((hsi*63+29)*1+lsi)*1] = fp250;
LIBINT2_REALTYPE fp263;
fp263 = inteval->roz[vi] * src3[((hsi*30+7)*1+lsi)*1];
LIBINT2_REALTYPE fp262;
fp262 = src2[((hsi*30+7)*1+lsi)*1] - fp263;
LIBINT2_REALTYPE fp264;
fp264 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp261;
fp261 = fp264 * fp262;
LIBINT2_REALTYPE fp266;
fp266 = inteval->WP_z[vi] * src1[((hsi*45+16)*1+lsi)*1];
LIBINT2_REALTYPE fp267;
fp267 = inteval->PA_z[vi] * src0[((hsi*45+16)*1+lsi)*1];
LIBINT2_REALTYPE fp265;
fp265 = fp267 + fp266;
LIBINT2_REALTYPE fp260;
fp260 = fp265 + fp261;
target[((hsi*63+28)*1+lsi)*1] = fp260;
LIBINT2_REALTYPE fp271;
fp271 = inteval->roz[vi] * src3[((hsi*30+6)*1+lsi)*1];
LIBINT2_REALTYPE fp270;
fp270 = src2[((hsi*30+6)*1+lsi)*1] - fp271;
LIBINT2_REALTYPE fp272;
fp272 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp269;
fp269 = fp272 * fp270;
LIBINT2_REALTYPE fp274;
fp274 = inteval->WP_z[vi] * src1[((hsi*45+15)*1+lsi)*1];
LIBINT2_REALTYPE fp275;
fp275 = inteval->PA_z[vi] * src0[((hsi*45+15)*1+lsi)*1];
LIBINT2_REALTYPE fp273;
fp273 = fp275 + fp274;
LIBINT2_REALTYPE fp268;
fp268 = fp273 + fp269;
target[((hsi*63+27)*1+lsi)*1] = fp268;
LIBINT2_REALTYPE fp277;
fp277 = inteval->oo2ze[vi] * src4[((hsi*15+4)*1+lsi)*1];
LIBINT2_REALTYPE fp281;
fp281 = inteval->roz[vi] * src3[((hsi*30+5)*1+lsi)*1];
LIBINT2_REALTYPE fp280;
fp280 = src2[((hsi*30+5)*1+lsi)*1] - fp281;
LIBINT2_REALTYPE fp279;
fp279 = inteval->oo2z[vi] * fp280;
LIBINT2_REALTYPE fp283;
fp283 = inteval->WP_z[vi] * src1[((hsi*45+14)*1+lsi)*1];
LIBINT2_REALTYPE fp284;
fp284 = inteval->PA_z[vi] * src0[((hsi*45+14)*1+lsi)*1];
LIBINT2_REALTYPE fp282;
fp282 = fp284 + fp283;
LIBINT2_REALTYPE fp278;
fp278 = fp282 + fp279;
LIBINT2_REALTYPE fp276;
fp276 = fp278 + fp277;
target[((hsi*63+26)*1+lsi)*1] = fp276;
LIBINT2_REALTYPE fp288;
fp288 = inteval->roz[vi] * src3[((hsi*30+4)*1+lsi)*1];
LIBINT2_REALTYPE fp287;
fp287 = src2[((hsi*30+4)*1+lsi)*1] - fp288;
LIBINT2_REALTYPE fp286;
fp286 = inteval->oo2z[vi] * fp287;
LIBINT2_REALTYPE fp290;
fp290 = inteval->WP_z[vi] * src1[((hsi*45+13)*1+lsi)*1];
LIBINT2_REALTYPE fp291;
fp291 = inteval->PA_z[vi] * src0[((hsi*45+13)*1+lsi)*1];
LIBINT2_REALTYPE fp289;
fp289 = fp291 + fp290;
LIBINT2_REALTYPE fp285;
fp285 = fp289 + fp286;
target[((hsi*63+25)*1+lsi)*1] = fp285;
LIBINT2_REALTYPE fp295;
fp295 = inteval->roz[vi] * src3[((hsi*30+3)*1+lsi)*1];
LIBINT2_REALTYPE fp294;
fp294 = src2[((hsi*30+3)*1+lsi)*1] - fp295;
LIBINT2_REALTYPE fp293;
fp293 = inteval->oo2z[vi] * fp294;
LIBINT2_REALTYPE fp297;
fp297 = inteval->WP_z[vi] * src1[((hsi*45+12)*1+lsi)*1];
LIBINT2_REALTYPE fp298;
fp298 = inteval->PA_z[vi] * src0[((hsi*45+12)*1+lsi)*1];
LIBINT2_REALTYPE fp296;
fp296 = fp298 + fp297;
LIBINT2_REALTYPE fp292;
fp292 = fp296 + fp293;
target[((hsi*63+24)*1+lsi)*1] = fp292;
LIBINT2_REALTYPE fp300;
fp300 = inteval->oo2ze[vi] * src4[((hsi*15+3)*1+lsi)*1];
LIBINT2_REALTYPE fp302;
fp302 = inteval->WP_z[vi] * src1[((hsi*45+11)*1+lsi)*1];
LIBINT2_REALTYPE fp303;
fp303 = inteval->PA_z[vi] * src0[((hsi*45+11)*1+lsi)*1];
LIBINT2_REALTYPE fp301;
fp301 = fp303 + fp302;
LIBINT2_REALTYPE fp299;
fp299 = fp301 + fp300;
target[((hsi*63+23)*1+lsi)*1] = fp299;
LIBINT2_REALTYPE fp305;
fp305 = inteval->WP_z[vi] * src1[((hsi*45+10)*1+lsi)*1];
LIBINT2_REALTYPE fp306;
fp306 = inteval->PA_z[vi] * src0[((hsi*45+10)*1+lsi)*1];
LIBINT2_REALTYPE fp304;
fp304 = fp306 + fp305;
target[((hsi*63+22)*1+lsi)*1] = fp304;
LIBINT2_REALTYPE fp308;
fp308 = inteval->WP_z[vi] * src1[((hsi*45+9)*1+lsi)*1];
LIBINT2_REALTYPE fp309;
fp309 = inteval->PA_z[vi] * src0[((hsi*45+9)*1+lsi)*1];
LIBINT2_REALTYPE fp307;
fp307 = fp309 + fp308;
target[((hsi*63+21)*1+lsi)*1] = fp307;
LIBINT2_REALTYPE fp313;
fp313 = inteval->roz[vi] * src3[((hsi*30+5)*1+lsi)*1];
LIBINT2_REALTYPE fp312;
fp312 = src2[((hsi*30+5)*1+lsi)*1] - fp313;
LIBINT2_REALTYPE fp314;
fp314 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp311;
fp311 = fp314 * fp312;
LIBINT2_REALTYPE fp316;
fp316 = inteval->WP_y[vi] * src1[((hsi*45+11)*1+lsi)*1];
LIBINT2_REALTYPE fp317;
fp317 = inteval->PA_y[vi] * src0[((hsi*45+11)*1+lsi)*1];
LIBINT2_REALTYPE fp315;
fp315 = fp317 + fp316;
LIBINT2_REALTYPE fp310;
fp310 = fp315 + fp311;
target[((hsi*63+20)*1+lsi)*1] = fp310;
LIBINT2_REALTYPE fp319;
fp319 = inteval->oo2ze[vi] * src4[((hsi*15+3)*1+lsi)*1];
LIBINT2_REALTYPE fp323;
fp323 = inteval->roz[vi] * src3[((hsi*30+4)*1+lsi)*1];
LIBINT2_REALTYPE fp322;
fp322 = src2[((hsi*30+4)*1+lsi)*1] - fp323;
LIBINT2_REALTYPE fp324;
fp324 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp321;
fp321 = fp324 * fp322;
LIBINT2_REALTYPE fp326;
fp326 = inteval->WP_y[vi] * src1[((hsi*45+10)*1+lsi)*1];
LIBINT2_REALTYPE fp327;
fp327 = inteval->PA_y[vi] * src0[((hsi*45+10)*1+lsi)*1];
LIBINT2_REALTYPE fp325;
fp325 = fp327 + fp326;
LIBINT2_REALTYPE fp320;
fp320 = fp325 + fp321;
LIBINT2_REALTYPE fp318;
fp318 = fp320 + fp319;
target[((hsi*63+19)*1+lsi)*1] = fp318;
LIBINT2_REALTYPE fp331;
fp331 = inteval->roz[vi] * src3[((hsi*30+3)*1+lsi)*1];
LIBINT2_REALTYPE fp330;
fp330 = src2[((hsi*30+3)*1+lsi)*1] - fp331;
LIBINT2_REALTYPE fp332;
fp332 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp329;
fp329 = fp332 * fp330;
LIBINT2_REALTYPE fp334;
fp334 = inteval->WP_y[vi] * src1[((hsi*45+9)*1+lsi)*1];
LIBINT2_REALTYPE fp335;
fp335 = inteval->PA_y[vi] * src0[((hsi*45+9)*1+lsi)*1];
LIBINT2_REALTYPE fp333;
fp333 = fp335 + fp334;
LIBINT2_REALTYPE fp328;
fp328 = fp333 + fp329;
target[((hsi*63+18)*1+lsi)*1] = fp328;
LIBINT2_REALTYPE fp337;
fp337 = inteval->oo2ze[vi] * src4[((hsi*15+2)*1+lsi)*1];
LIBINT2_REALTYPE fp341;
fp341 = inteval->roz[vi] * src3[((hsi*30+2)*1+lsi)*1];
LIBINT2_REALTYPE fp340;
fp340 = src2[((hsi*30+2)*1+lsi)*1] - fp341;
LIBINT2_REALTYPE fp339;
fp339 = inteval->oo2z[vi] * fp340;
LIBINT2_REALTYPE fp343;
fp343 = inteval->WP_z[vi] * src1[((hsi*45+8)*1+lsi)*1];
LIBINT2_REALTYPE fp344;
fp344 = inteval->PA_z[vi] * src0[((hsi*45+8)*1+lsi)*1];
LIBINT2_REALTYPE fp342;
fp342 = fp344 + fp343;
LIBINT2_REALTYPE fp338;
fp338 = fp342 + fp339;
LIBINT2_REALTYPE fp336;
fp336 = fp338 + fp337;
target[((hsi*63+17)*1+lsi)*1] = fp336;
LIBINT2_REALTYPE fp348;
fp348 = inteval->roz[vi] * src3[((hsi*30+1)*1+lsi)*1];
LIBINT2_REALTYPE fp347;
fp347 = src2[((hsi*30+1)*1+lsi)*1] - fp348;
LIBINT2_REALTYPE fp346;
fp346 = inteval->oo2z[vi] * fp347;
LIBINT2_REALTYPE fp350;
fp350 = inteval->WP_z[vi] * src1[((hsi*45+7)*1+lsi)*1];
LIBINT2_REALTYPE fp351;
fp351 = inteval->PA_z[vi] * src0[((hsi*45+7)*1+lsi)*1];
LIBINT2_REALTYPE fp349;
fp349 = fp351 + fp350;
LIBINT2_REALTYPE fp345;
fp345 = fp349 + fp346;
target[((hsi*63+16)*1+lsi)*1] = fp345;
LIBINT2_REALTYPE fp355;
fp355 = inteval->roz[vi] * src3[((hsi*30+0)*1+lsi)*1];
LIBINT2_REALTYPE fp354;
fp354 = src2[((hsi*30+0)*1+lsi)*1] - fp355;
LIBINT2_REALTYPE fp353;
fp353 = inteval->oo2z[vi] * fp354;
LIBINT2_REALTYPE fp357;
fp357 = inteval->WP_z[vi] * src1[((hsi*45+6)*1+lsi)*1];
LIBINT2_REALTYPE fp358;
fp358 = inteval->PA_z[vi] * src0[((hsi*45+6)*1+lsi)*1];
LIBINT2_REALTYPE fp356;
fp356 = fp358 + fp357;
LIBINT2_REALTYPE fp352;
fp352 = fp356 + fp353;
target[((hsi*63+15)*1+lsi)*1] = fp352;
LIBINT2_REALTYPE fp360;
fp360 = inteval->oo2ze[vi] * src4[((hsi*15+1)*1+lsi)*1];
LIBINT2_REALTYPE fp362;
fp362 = inteval->WP_z[vi] * src1[((hsi*45+5)*1+lsi)*1];
LIBINT2_REALTYPE fp363;
fp363 = inteval->PA_z[vi] * src0[((hsi*45+5)*1+lsi)*1];
LIBINT2_REALTYPE fp361;
fp361 = fp363 + fp362;
LIBINT2_REALTYPE fp359;
fp359 = fp361 + fp360;
target[((hsi*63+14)*1+lsi)*1] = fp359;
LIBINT2_REALTYPE fp365;
fp365 = inteval->WP_z[vi] * src1[((hsi*45+4)*1+lsi)*1];
LIBINT2_REALTYPE fp366;
fp366 = inteval->PA_z[vi] * src0[((hsi*45+4)*1+lsi)*1];
LIBINT2_REALTYPE fp364;
fp364 = fp366 + fp365;
target[((hsi*63+13)*1+lsi)*1] = fp364;
LIBINT2_REALTYPE fp368;
fp368 = inteval->WP_z[vi] * src1[((hsi*45+3)*1+lsi)*1];
LIBINT2_REALTYPE fp369;
fp369 = inteval->PA_z[vi] * src0[((hsi*45+3)*1+lsi)*1];
LIBINT2_REALTYPE fp367;
fp367 = fp369 + fp368;
target[((hsi*63+12)*1+lsi)*1] = fp367;
LIBINT2_REALTYPE fp373;
fp373 = inteval->roz[vi] * src3[((hsi*30+2)*1+lsi)*1];
LIBINT2_REALTYPE fp372;
fp372 = src2[((hsi*30+2)*1+lsi)*1] - fp373;
LIBINT2_REALTYPE fp371;
fp371 = inteval->oo2z[vi] * fp372;
LIBINT2_REALTYPE fp375;
fp375 = inteval->WP_y[vi] * src1[((hsi*45+5)*1+lsi)*1];
LIBINT2_REALTYPE fp376;
fp376 = inteval->PA_y[vi] * src0[((hsi*45+5)*1+lsi)*1];
LIBINT2_REALTYPE fp374;
fp374 = fp376 + fp375;
LIBINT2_REALTYPE fp370;
fp370 = fp374 + fp371;
target[((hsi*63+11)*1+lsi)*1] = fp370;
LIBINT2_REALTYPE fp378;
fp378 = inteval->oo2ze[vi] * src4[((hsi*15+1)*1+lsi)*1];
LIBINT2_REALTYPE fp382;
fp382 = inteval->roz[vi] * src3[((hsi*30+1)*1+lsi)*1];
LIBINT2_REALTYPE fp381;
fp381 = src2[((hsi*30+1)*1+lsi)*1] - fp382;
LIBINT2_REALTYPE fp380;
fp380 = inteval->oo2z[vi] * fp381;
LIBINT2_REALTYPE fp384;
fp384 = inteval->WP_y[vi] * src1[((hsi*45+4)*1+lsi)*1];
LIBINT2_REALTYPE fp385;
fp385 = inteval->PA_y[vi] * src0[((hsi*45+4)*1+lsi)*1];
LIBINT2_REALTYPE fp383;
fp383 = fp385 + fp384;
LIBINT2_REALTYPE fp379;
fp379 = fp383 + fp380;
LIBINT2_REALTYPE fp377;
fp377 = fp379 + fp378;
target[((hsi*63+10)*1+lsi)*1] = fp377;
LIBINT2_REALTYPE fp389;
fp389 = inteval->roz[vi] * src3[((hsi*30+0)*1+lsi)*1];
LIBINT2_REALTYPE fp388;
fp388 = src2[((hsi*30+0)*1+lsi)*1] - fp389;
LIBINT2_REALTYPE fp387;
fp387 = inteval->oo2z[vi] * fp388;
LIBINT2_REALTYPE fp391;
fp391 = inteval->WP_y[vi] * src1[((hsi*45+3)*1+lsi)*1];
LIBINT2_REALTYPE fp392;
fp392 = inteval->PA_y[vi] * src0[((hsi*45+3)*1+lsi)*1];
LIBINT2_REALTYPE fp390;
fp390 = fp392 + fp391;
LIBINT2_REALTYPE fp386;
fp386 = fp390 + fp387;
target[((hsi*63+9)*1+lsi)*1] = fp386;
LIBINT2_REALTYPE fp394;
fp394 = inteval->oo2ze[vi] * src4[((hsi*15+0)*1+lsi)*1];
LIBINT2_REALTYPE fp396;
fp396 = inteval->WP_z[vi] * src1[((hsi*45+2)*1+lsi)*1];
LIBINT2_REALTYPE fp397;
fp397 = inteval->PA_z[vi] * src0[((hsi*45+2)*1+lsi)*1];
LIBINT2_REALTYPE fp395;
fp395 = fp397 + fp396;
LIBINT2_REALTYPE fp393;
fp393 = fp395 + fp394;
target[((hsi*63+8)*1+lsi)*1] = fp393;
LIBINT2_REALTYPE fp399;
fp399 = inteval->WP_z[vi] * src1[((hsi*45+1)*1+lsi)*1];
LIBINT2_REALTYPE fp400;
fp400 = inteval->PA_z[vi] * src0[((hsi*45+1)*1+lsi)*1];
LIBINT2_REALTYPE fp398;
fp398 = fp400 + fp399;
target[((hsi*63+7)*1+lsi)*1] = fp398;
LIBINT2_REALTYPE fp402;
fp402 = inteval->WP_z[vi] * src1[((hsi*45+0)*1+lsi)*1];
LIBINT2_REALTYPE fp403;
fp403 = inteval->PA_z[vi] * src0[((hsi*45+0)*1+lsi)*1];
LIBINT2_REALTYPE fp401;
fp401 = fp403 + fp402;
target[((hsi*63+6)*1+lsi)*1] = fp401;
LIBINT2_REALTYPE fp405;
fp405 = inteval->WP_y[vi] * src1[((hsi*45+2)*1+lsi)*1];
LIBINT2_REALTYPE fp406;
fp406 = inteval->PA_y[vi] * src0[((hsi*45+2)*1+lsi)*1];
LIBINT2_REALTYPE fp404;
fp404 = fp406 + fp405;
target[((hsi*63+5)*1+lsi)*1] = fp404;
LIBINT2_REALTYPE fp408;
fp408 = inteval->oo2ze[vi] * src4[((hsi*15+0)*1+lsi)*1];
LIBINT2_REALTYPE fp410;
fp410 = inteval->WP_y[vi] * src1[((hsi*45+1)*1+lsi)*1];
LIBINT2_REALTYPE fp411;
fp411 = inteval->PA_y[vi] * src0[((hsi*45+1)*1+lsi)*1];
LIBINT2_REALTYPE fp409;
fp409 = fp411 + fp410;
LIBINT2_REALTYPE fp407;
fp407 = fp409 + fp408;
target[((hsi*63+4)*1+lsi)*1] = fp407;
LIBINT2_REALTYPE fp413;
fp413 = inteval->WP_y[vi] * src1[((hsi*45+0)*1+lsi)*1];
LIBINT2_REALTYPE fp414;
fp414 = inteval->PA_y[vi] * src0[((hsi*45+0)*1+lsi)*1];
LIBINT2_REALTYPE fp412;
fp412 = fp414 + fp413;
target[((hsi*63+3)*1+lsi)*1] = fp412;
LIBINT2_REALTYPE fp418;
fp418 = inteval->roz[vi] * src3[((hsi*30+2)*1+lsi)*1];
LIBINT2_REALTYPE fp417;
fp417 = src2[((hsi*30+2)*1+lsi)*1] - fp418;
LIBINT2_REALTYPE fp419;
fp419 = 4 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp416;
fp416 = fp419 * fp417;
LIBINT2_REALTYPE fp421;
fp421 = inteval->WP_x[vi] * src1[((hsi*45+2)*1+lsi)*1];
LIBINT2_REALTYPE fp422;
fp422 = inteval->PA_x[vi] * src0[((hsi*45+2)*1+lsi)*1];
LIBINT2_REALTYPE fp420;
fp420 = fp422 + fp421;
LIBINT2_REALTYPE fp415;
fp415 = fp420 + fp416;
target[((hsi*63+2)*1+lsi)*1] = fp415;
LIBINT2_REALTYPE fp426;
fp426 = inteval->roz[vi] * src3[((hsi*30+1)*1+lsi)*1];
LIBINT2_REALTYPE fp425;
fp425 = src2[((hsi*30+1)*1+lsi)*1] - fp426;
LIBINT2_REALTYPE fp427;
fp427 = 4 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp424;
fp424 = fp427 * fp425;
LIBINT2_REALTYPE fp429;
fp429 = inteval->WP_x[vi] * src1[((hsi*45+1)*1+lsi)*1];
LIBINT2_REALTYPE fp430;
fp430 = inteval->PA_x[vi] * src0[((hsi*45+1)*1+lsi)*1];
LIBINT2_REALTYPE fp428;
fp428 = fp430 + fp429;
LIBINT2_REALTYPE fp423;
fp423 = fp428 + fp424;
target[((hsi*63+1)*1+lsi)*1] = fp423;
LIBINT2_REALTYPE fp432;
fp432 = inteval->oo2ze[vi] * src4[((hsi*15+0)*1+lsi)*1];
LIBINT2_REALTYPE fp436;
fp436 = inteval->roz[vi] * src3[((hsi*30+0)*1+lsi)*1];
LIBINT2_REALTYPE fp435;
fp435 = src2[((hsi*30+0)*1+lsi)*1] - fp436;
LIBINT2_REALTYPE fp437;
fp437 = 4 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp434;
fp434 = fp437 * fp435;
LIBINT2_REALTYPE fp439;
fp439 = inteval->WP_x[vi] * src1[((hsi*45+0)*1+lsi)*1];
LIBINT2_REALTYPE fp440;
fp440 = inteval->PA_x[vi] * src0[((hsi*45+0)*1+lsi)*1];
LIBINT2_REALTYPE fp438;
fp438 = fp440 + fp439;
LIBINT2_REALTYPE fp433;
fp433 = fp438 + fp434;
LIBINT2_REALTYPE fp431;
fp431 = fp433 + fp432;
target[((hsi*63+0)*1+lsi)*1] = fp431;
LIBINT2_REALTYPE fp1;
fp1 = inteval->oo2ze[vi] * src4[((hsi*15+14)*1+lsi)*1];
LIBINT2_REALTYPE fp5;
fp5 = inteval->roz[vi] * src3[((hsi*30+29)*1+lsi)*1];
LIBINT2_REALTYPE fp4;
fp4 = src2[((hsi*30+29)*1+lsi)*1] - fp5;
LIBINT2_REALTYPE fp6;
fp6 = 4 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp3;
fp3 = fp6 * fp4;
LIBINT2_REALTYPE fp8;
fp8 = inteval->WP_z[vi] * src1[((hsi*45+44)*1+lsi)*1];
LIBINT2_REALTYPE fp9;
fp9 = inteval->PA_z[vi] * src0[((hsi*45+44)*1+lsi)*1];
LIBINT2_REALTYPE fp7;
fp7 = fp9 + fp8;
LIBINT2_REALTYPE fp2;
fp2 = fp7 + fp3;
LIBINT2_REALTYPE fp0;
fp0 = fp2 + fp1;
target[((hsi*63+62)*1+lsi)*1] = fp0;
LIBINT2_REALTYPE fp13;
fp13 = inteval->roz[vi] * src3[((hsi*30+28)*1+lsi)*1];
LIBINT2_REALTYPE fp12;
fp12 = src2[((hsi*30+28)*1+lsi)*1] - fp13;
LIBINT2_REALTYPE fp14;
fp14 = 4 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp11;
fp11 = fp14 * fp12;
LIBINT2_REALTYPE fp16;
fp16 = inteval->WP_z[vi] * src1[((hsi*45+43)*1+lsi)*1];
LIBINT2_REALTYPE fp17;
fp17 = inteval->PA_z[vi] * src0[((hsi*45+43)*1+lsi)*1];
LIBINT2_REALTYPE fp15;
fp15 = fp17 + fp16;
LIBINT2_REALTYPE fp10;
fp10 = fp15 + fp11;
target[((hsi*63+61)*1+lsi)*1] = fp10;
LIBINT2_REALTYPE fp21;
fp21 = inteval->roz[vi] * src3[((hsi*30+27)*1+lsi)*1];
LIBINT2_REALTYPE fp20;
fp20 = src2[((hsi*30+27)*1+lsi)*1] - fp21;
LIBINT2_REALTYPE fp22;
fp22 = 4 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp19;
fp19 = fp22 * fp20;
LIBINT2_REALTYPE fp24;
fp24 = inteval->WP_z[vi] * src1[((hsi*45+42)*1+lsi)*1];
LIBINT2_REALTYPE fp25;
fp25 = inteval->PA_z[vi] * src0[((hsi*45+42)*1+lsi)*1];
LIBINT2_REALTYPE fp23;
fp23 = fp25 + fp24;
LIBINT2_REALTYPE fp18;
fp18 = fp23 + fp19;
target[((hsi*63+60)*1+lsi)*1] = fp18;
LIBINT2_REALTYPE fp27;
fp27 = inteval->oo2ze[vi] * src4[((hsi*15+13)*1+lsi)*1];
LIBINT2_REALTYPE fp31;
fp31 = inteval->roz[vi] * src3[((hsi*30+26)*1+lsi)*1];
LIBINT2_REALTYPE fp30;
fp30 = src2[((hsi*30+26)*1+lsi)*1] - fp31;
LIBINT2_REALTYPE fp32;
fp32 = 3 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp29;
fp29 = fp32 * fp30;
LIBINT2_REALTYPE fp34;
fp34 = inteval->WP_z[vi] * src1[((hsi*45+41)*1+lsi)*1];
LIBINT2_REALTYPE fp35;
fp35 = inteval->PA_z[vi] * src0[((hsi*45+41)*1+lsi)*1];
LIBINT2_REALTYPE fp33;
fp33 = fp35 + fp34;
LIBINT2_REALTYPE fp28;
fp28 = fp33 + fp29;
LIBINT2_REALTYPE fp26;
fp26 = fp28 + fp27;
target[((hsi*63+59)*1+lsi)*1] = fp26;
LIBINT2_REALTYPE fp39;
fp39 = inteval->roz[vi] * src3[((hsi*30+25)*1+lsi)*1];
LIBINT2_REALTYPE fp38;
fp38 = src2[((hsi*30+25)*1+lsi)*1] - fp39;
LIBINT2_REALTYPE fp40;
fp40 = 3 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp37;
fp37 = fp40 * fp38;
LIBINT2_REALTYPE fp42;
fp42 = inteval->WP_z[vi] * src1[((hsi*45+40)*1+lsi)*1];
LIBINT2_REALTYPE fp43;
fp43 = inteval->PA_z[vi] * src0[((hsi*45+40)*1+lsi)*1];
LIBINT2_REALTYPE fp41;
fp41 = fp43 + fp42;
LIBINT2_REALTYPE fp36;
fp36 = fp41 + fp37;
target[((hsi*63+58)*1+lsi)*1] = fp36;
LIBINT2_REALTYPE fp47;
fp47 = inteval->roz[vi] * src3[((hsi*30+24)*1+lsi)*1];
LIBINT2_REALTYPE fp46;
fp46 = src2[((hsi*30+24)*1+lsi)*1] - fp47;
LIBINT2_REALTYPE fp48;
fp48 = 3 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp45;
fp45 = fp48 * fp46;
LIBINT2_REALTYPE fp50;
fp50 = inteval->WP_z[vi] * src1[((hsi*45+39)*1+lsi)*1];
LIBINT2_REALTYPE fp51;
fp51 = inteval->PA_z[vi] * src0[((hsi*45+39)*1+lsi)*1];
LIBINT2_REALTYPE fp49;
fp49 = fp51 + fp50;
LIBINT2_REALTYPE fp44;
fp44 = fp49 + fp45;
target[((hsi*63+57)*1+lsi)*1] = fp44;
LIBINT2_REALTYPE fp53;
fp53 = inteval->oo2ze[vi] * src4[((hsi*15+12)*1+lsi)*1];
LIBINT2_REALTYPE fp57;
fp57 = inteval->roz[vi] * src3[((hsi*30+23)*1+lsi)*1];
LIBINT2_REALTYPE fp56;
fp56 = src2[((hsi*30+23)*1+lsi)*1] - fp57;
LIBINT2_REALTYPE fp58;
fp58 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp55;
fp55 = fp58 * fp56;
LIBINT2_REALTYPE fp60;
fp60 = inteval->WP_z[vi] * src1[((hsi*45+38)*1+lsi)*1];
LIBINT2_REALTYPE fp61;
fp61 = inteval->PA_z[vi] * src0[((hsi*45+38)*1+lsi)*1];
LIBINT2_REALTYPE fp59;
fp59 = fp61 + fp60;
LIBINT2_REALTYPE fp54;
fp54 = fp59 + fp55;
LIBINT2_REALTYPE fp52;
fp52 = fp54 + fp53;
target[((hsi*63+56)*1+lsi)*1] = fp52;
LIBINT2_REALTYPE fp65;
fp65 = inteval->roz[vi] * src3[((hsi*30+22)*1+lsi)*1];
LIBINT2_REALTYPE fp64;
fp64 = src2[((hsi*30+22)*1+lsi)*1] - fp65;
LIBINT2_REALTYPE fp66;
fp66 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp63;
fp63 = fp66 * fp64;
LIBINT2_REALTYPE fp68;
fp68 = inteval->WP_z[vi] * src1[((hsi*45+37)*1+lsi)*1];
LIBINT2_REALTYPE fp69;
fp69 = inteval->PA_z[vi] * src0[((hsi*45+37)*1+lsi)*1];
LIBINT2_REALTYPE fp67;
fp67 = fp69 + fp68;
LIBINT2_REALTYPE fp62;
fp62 = fp67 + fp63;
target[((hsi*63+55)*1+lsi)*1] = fp62;
LIBINT2_REALTYPE fp73;
fp73 = inteval->roz[vi] * src3[((hsi*30+21)*1+lsi)*1];
LIBINT2_REALTYPE fp72;
fp72 = src2[((hsi*30+21)*1+lsi)*1] - fp73;
LIBINT2_REALTYPE fp74;
fp74 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp71;
fp71 = fp74 * fp72;
LIBINT2_REALTYPE fp76;
fp76 = inteval->WP_z[vi] * src1[((hsi*45+36)*1+lsi)*1];
LIBINT2_REALTYPE fp77;
fp77 = inteval->PA_z[vi] * src0[((hsi*45+36)*1+lsi)*1];
LIBINT2_REALTYPE fp75;
fp75 = fp77 + fp76;
LIBINT2_REALTYPE fp70;
fp70 = fp75 + fp71;
target[((hsi*63+54)*1+lsi)*1] = fp70;
LIBINT2_REALTYPE fp79;
fp79 = inteval->oo2ze[vi] * src4[((hsi*15+11)*1+lsi)*1];
LIBINT2_REALTYPE fp83;
fp83 = inteval->roz[vi] * src3[((hsi*30+20)*1+lsi)*1];
LIBINT2_REALTYPE fp82;
fp82 = src2[((hsi*30+20)*1+lsi)*1] - fp83;
LIBINT2_REALTYPE fp81;
fp81 = inteval->oo2z[vi] * fp82;
LIBINT2_REALTYPE fp85;
fp85 = inteval->WP_z[vi] * src1[((hsi*45+35)*1+lsi)*1];
LIBINT2_REALTYPE fp86;
fp86 = inteval->PA_z[vi] * src0[((hsi*45+35)*1+lsi)*1];
LIBINT2_REALTYPE fp84;
fp84 = fp86 + fp85;
LIBINT2_REALTYPE fp80;
fp80 = fp84 + fp81;
LIBINT2_REALTYPE fp78;
fp78 = fp80 + fp79;
target[((hsi*63+53)*1+lsi)*1] = fp78;
LIBINT2_REALTYPE fp90;
fp90 = inteval->roz[vi] * src3[((hsi*30+19)*1+lsi)*1];
LIBINT2_REALTYPE fp89;
fp89 = src2[((hsi*30+19)*1+lsi)*1] - fp90;
LIBINT2_REALTYPE fp88;
fp88 = inteval->oo2z[vi] * fp89;
LIBINT2_REALTYPE fp92;
fp92 = inteval->WP_z[vi] * src1[((hsi*45+34)*1+lsi)*1];
LIBINT2_REALTYPE fp93;
fp93 = inteval->PA_z[vi] * src0[((hsi*45+34)*1+lsi)*1];
LIBINT2_REALTYPE fp91;
fp91 = fp93 + fp92;
LIBINT2_REALTYPE fp87;
fp87 = fp91 + fp88;
target[((hsi*63+52)*1+lsi)*1] = fp87;
LIBINT2_REALTYPE fp97;
fp97 = inteval->roz[vi] * src3[((hsi*30+18)*1+lsi)*1];
LIBINT2_REALTYPE fp96;
fp96 = src2[((hsi*30+18)*1+lsi)*1] - fp97;
LIBINT2_REALTYPE fp95;
fp95 = inteval->oo2z[vi] * fp96;
LIBINT2_REALTYPE fp99;
fp99 = inteval->WP_z[vi] * src1[((hsi*45+33)*1+lsi)*1];
LIBINT2_REALTYPE fp100;
fp100 = inteval->PA_z[vi] * src0[((hsi*45+33)*1+lsi)*1];
LIBINT2_REALTYPE fp98;
fp98 = fp100 + fp99;
LIBINT2_REALTYPE fp94;
fp94 = fp98 + fp95;
target[((hsi*63+51)*1+lsi)*1] = fp94;
LIBINT2_REALTYPE fp102;
fp102 = inteval->oo2ze[vi] * src4[((hsi*15+10)*1+lsi)*1];
LIBINT2_REALTYPE fp104;
fp104 = inteval->WP_z[vi] * src1[((hsi*45+32)*1+lsi)*1];
LIBINT2_REALTYPE fp105;
fp105 = inteval->PA_z[vi] * src0[((hsi*45+32)*1+lsi)*1];
LIBINT2_REALTYPE fp103;
fp103 = fp105 + fp104;
LIBINT2_REALTYPE fp101;
fp101 = fp103 + fp102;
target[((hsi*63+50)*1+lsi)*1] = fp101;
LIBINT2_REALTYPE fp107;
fp107 = inteval->WP_z[vi] * src1[((hsi*45+31)*1+lsi)*1];
LIBINT2_REALTYPE fp108;
fp108 = inteval->PA_z[vi] * src0[((hsi*45+31)*1+lsi)*1];
LIBINT2_REALTYPE fp106;
fp106 = fp108 + fp107;
target[((hsi*63+49)*1+lsi)*1] = fp106;
LIBINT2_REALTYPE fp110;
fp110 = inteval->WP_z[vi] * src1[((hsi*45+30)*1+lsi)*1];
LIBINT2_REALTYPE fp111;
fp111 = inteval->PA_z[vi] * src0[((hsi*45+30)*1+lsi)*1];
LIBINT2_REALTYPE fp109;
fp109 = fp111 + fp110;
target[((hsi*63+48)*1+lsi)*1] = fp109;
LIBINT2_REALTYPE fp115;
fp115 = inteval->roz[vi] * src3[((hsi*30+20)*1+lsi)*1];
LIBINT2_REALTYPE fp114;
fp114 = src2[((hsi*30+20)*1+lsi)*1] - fp115;
LIBINT2_REALTYPE fp116;
fp116 = 4 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp113;
fp113 = fp116 * fp114;
LIBINT2_REALTYPE fp118;
fp118 = inteval->WP_y[vi] * src1[((hsi*45+32)*1+lsi)*1];
LIBINT2_REALTYPE fp119;
fp119 = inteval->PA_y[vi] * src0[((hsi*45+32)*1+lsi)*1];
LIBINT2_REALTYPE fp117;
fp117 = fp119 + fp118;
LIBINT2_REALTYPE fp112;
fp112 = fp117 + fp113;
target[((hsi*63+47)*1+lsi)*1] = fp112;
LIBINT2_REALTYPE fp121;
fp121 = inteval->oo2ze[vi] * src4[((hsi*15+10)*1+lsi)*1];
LIBINT2_REALTYPE fp125;
fp125 = inteval->roz[vi] * src3[((hsi*30+19)*1+lsi)*1];
LIBINT2_REALTYPE fp124;
fp124 = src2[((hsi*30+19)*1+lsi)*1] - fp125;
LIBINT2_REALTYPE fp126;
fp126 = 4 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp123;
fp123 = fp126 * fp124;
LIBINT2_REALTYPE fp128;
fp128 = inteval->WP_y[vi] * src1[((hsi*45+31)*1+lsi)*1];
LIBINT2_REALTYPE fp129;
fp129 = inteval->PA_y[vi] * src0[((hsi*45+31)*1+lsi)*1];
LIBINT2_REALTYPE fp127;
fp127 = fp129 + fp128;
LIBINT2_REALTYPE fp122;
fp122 = fp127 + fp123;
LIBINT2_REALTYPE fp120;
fp120 = fp122 + fp121;
target[((hsi*63+46)*1+lsi)*1] = fp120;
LIBINT2_REALTYPE fp133;
fp133 = inteval->roz[vi] * src3[((hsi*30+18)*1+lsi)*1];
LIBINT2_REALTYPE fp132;
fp132 = src2[((hsi*30+18)*1+lsi)*1] - fp133;
LIBINT2_REALTYPE fp134;
fp134 = 4 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp131;
fp131 = fp134 * fp132;
LIBINT2_REALTYPE fp136;
fp136 = inteval->WP_y[vi] * src1[((hsi*45+30)*1+lsi)*1];
LIBINT2_REALTYPE fp137;
fp137 = inteval->PA_y[vi] * src0[((hsi*45+30)*1+lsi)*1];
LIBINT2_REALTYPE fp135;
fp135 = fp137 + fp136;
LIBINT2_REALTYPE fp130;
fp130 = fp135 + fp131;
target[((hsi*63+45)*1+lsi)*1] = fp130;
LIBINT2_REALTYPE fp139;
fp139 = inteval->oo2ze[vi] * src4[((hsi*15+9)*1+lsi)*1];
LIBINT2_REALTYPE fp143;
fp143 = inteval->roz[vi] * src3[((hsi*30+17)*1+lsi)*1];
LIBINT2_REALTYPE fp142;
fp142 = src2[((hsi*30+17)*1+lsi)*1] - fp143;
LIBINT2_REALTYPE fp144;
fp144 = 3 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp141;
fp141 = fp144 * fp142;
LIBINT2_REALTYPE fp146;
fp146 = inteval->WP_z[vi] * src1[((hsi*45+29)*1+lsi)*1];
LIBINT2_REALTYPE fp147;
fp147 = inteval->PA_z[vi] * src0[((hsi*45+29)*1+lsi)*1];
LIBINT2_REALTYPE fp145;
fp145 = fp147 + fp146;
LIBINT2_REALTYPE fp140;
fp140 = fp145 + fp141;
LIBINT2_REALTYPE fp138;
fp138 = fp140 + fp139;
target[((hsi*63+44)*1+lsi)*1] = fp138;
LIBINT2_REALTYPE fp151;
fp151 = inteval->roz[vi] * src3[((hsi*30+16)*1+lsi)*1];
LIBINT2_REALTYPE fp150;
fp150 = src2[((hsi*30+16)*1+lsi)*1] - fp151;
LIBINT2_REALTYPE fp152;
fp152 = 3 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp149;
fp149 = fp152 * fp150;
LIBINT2_REALTYPE fp154;
fp154 = inteval->WP_z[vi] * src1[((hsi*45+28)*1+lsi)*1];
LIBINT2_REALTYPE fp155;
fp155 = inteval->PA_z[vi] * src0[((hsi*45+28)*1+lsi)*1];
LIBINT2_REALTYPE fp153;
fp153 = fp155 + fp154;
LIBINT2_REALTYPE fp148;
fp148 = fp153 + fp149;
target[((hsi*63+43)*1+lsi)*1] = fp148;
LIBINT2_REALTYPE fp159;
fp159 = inteval->roz[vi] * src3[((hsi*30+15)*1+lsi)*1];
LIBINT2_REALTYPE fp158;
fp158 = src2[((hsi*30+15)*1+lsi)*1] - fp159;
LIBINT2_REALTYPE fp160;
fp160 = 3 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp157;
fp157 = fp160 * fp158;
LIBINT2_REALTYPE fp162;
fp162 = inteval->WP_z[vi] * src1[((hsi*45+27)*1+lsi)*1];
LIBINT2_REALTYPE fp163;
fp163 = inteval->PA_z[vi] * src0[((hsi*45+27)*1+lsi)*1];
LIBINT2_REALTYPE fp161;
fp161 = fp163 + fp162;
LIBINT2_REALTYPE fp156;
fp156 = fp161 + fp157;
target[((hsi*63+42)*1+lsi)*1] = fp156;
LIBINT2_REALTYPE fp165;
fp165 = inteval->oo2ze[vi] * src4[((hsi*15+8)*1+lsi)*1];
LIBINT2_REALTYPE fp169;
fp169 = inteval->roz[vi] * src3[((hsi*30+14)*1+lsi)*1];
LIBINT2_REALTYPE fp168;
fp168 = src2[((hsi*30+14)*1+lsi)*1] - fp169;
LIBINT2_REALTYPE fp170;
fp170 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp167;
fp167 = fp170 * fp168;
LIBINT2_REALTYPE fp172;
fp172 = inteval->WP_z[vi] * src1[((hsi*45+26)*1+lsi)*1];
LIBINT2_REALTYPE fp173;
fp173 = inteval->PA_z[vi] * src0[((hsi*45+26)*1+lsi)*1];
LIBINT2_REALTYPE fp171;
fp171 = fp173 + fp172;
LIBINT2_REALTYPE fp166;
fp166 = fp171 + fp167;
LIBINT2_REALTYPE fp164;
fp164 = fp166 + fp165;
target[((hsi*63+41)*1+lsi)*1] = fp164;
LIBINT2_REALTYPE fp177;
fp177 = inteval->roz[vi] * src3[((hsi*30+13)*1+lsi)*1];
LIBINT2_REALTYPE fp176;
fp176 = src2[((hsi*30+13)*1+lsi)*1] - fp177;
LIBINT2_REALTYPE fp178;
fp178 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp175;
fp175 = fp178 * fp176;
LIBINT2_REALTYPE fp180;
fp180 = inteval->WP_z[vi] * src1[((hsi*45+25)*1+lsi)*1];
LIBINT2_REALTYPE fp181;
fp181 = inteval->PA_z[vi] * src0[((hsi*45+25)*1+lsi)*1];
LIBINT2_REALTYPE fp179;
fp179 = fp181 + fp180;
LIBINT2_REALTYPE fp174;
fp174 = fp179 + fp175;
target[((hsi*63+40)*1+lsi)*1] = fp174;
LIBINT2_REALTYPE fp185;
fp185 = inteval->roz[vi] * src3[((hsi*30+12)*1+lsi)*1];
LIBINT2_REALTYPE fp184;
fp184 = src2[((hsi*30+12)*1+lsi)*1] - fp185;
LIBINT2_REALTYPE fp186;
fp186 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp183;
fp183 = fp186 * fp184;
LIBINT2_REALTYPE fp188;
fp188 = inteval->WP_z[vi] * src1[((hsi*45+24)*1+lsi)*1];
LIBINT2_REALTYPE fp189;
fp189 = inteval->PA_z[vi] * src0[((hsi*45+24)*1+lsi)*1];
LIBINT2_REALTYPE fp187;
fp187 = fp189 + fp188;
LIBINT2_REALTYPE fp182;
fp182 = fp187 + fp183;
target[((hsi*63+39)*1+lsi)*1] = fp182;
LIBINT2_REALTYPE fp191;
fp191 = inteval->oo2ze[vi] * src4[((hsi*15+7)*1+lsi)*1];
LIBINT2_REALTYPE fp195;
fp195 = inteval->roz[vi] * src3[((hsi*30+11)*1+lsi)*1];
LIBINT2_REALTYPE fp194;
fp194 = src2[((hsi*30+11)*1+lsi)*1] - fp195;
LIBINT2_REALTYPE fp193;
fp193 = inteval->oo2z[vi] * fp194;
LIBINT2_REALTYPE fp197;
fp197 = inteval->WP_z[vi] * src1[((hsi*45+23)*1+lsi)*1];
LIBINT2_REALTYPE fp198;
fp198 = inteval->PA_z[vi] * src0[((hsi*45+23)*1+lsi)*1];
LIBINT2_REALTYPE fp196;
fp196 = fp198 + fp197;
LIBINT2_REALTYPE fp192;
fp192 = fp196 + fp193;
LIBINT2_REALTYPE fp190;
fp190 = fp192 + fp191;
target[((hsi*63+38)*1+lsi)*1] = fp190;
LIBINT2_REALTYPE fp202;
fp202 = inteval->roz[vi] * src3[((hsi*30+10)*1+lsi)*1];
LIBINT2_REALTYPE fp201;
fp201 = src2[((hsi*30+10)*1+lsi)*1] - fp202;
LIBINT2_REALTYPE fp200;
fp200 = inteval->oo2z[vi] * fp201;
LIBINT2_REALTYPE fp204;
fp204 = inteval->WP_z[vi] * src1[((hsi*45+22)*1+lsi)*1];
LIBINT2_REALTYPE fp205;
fp205 = inteval->PA_z[vi] * src0[((hsi*45+22)*1+lsi)*1];
LIBINT2_REALTYPE fp203;
fp203 = fp205 + fp204;
LIBINT2_REALTYPE fp199;
fp199 = fp203 + fp200;
target[((hsi*63+37)*1+lsi)*1] = fp199;
LIBINT2_REALTYPE fp209;
fp209 = inteval->roz[vi] * src3[((hsi*30+9)*1+lsi)*1];
LIBINT2_REALTYPE fp208;
fp208 = src2[((hsi*30+9)*1+lsi)*1] - fp209;
LIBINT2_REALTYPE fp207;
fp207 = inteval->oo2z[vi] * fp208;
LIBINT2_REALTYPE fp211;
fp211 = inteval->WP_z[vi] * src1[((hsi*45+21)*1+lsi)*1];
LIBINT2_REALTYPE fp212;
fp212 = inteval->PA_z[vi] * src0[((hsi*45+21)*1+lsi)*1];
LIBINT2_REALTYPE fp210;
fp210 = fp212 + fp211;
LIBINT2_REALTYPE fp206;
fp206 = fp210 + fp207;
target[((hsi*63+36)*1+lsi)*1] = fp206;
LIBINT2_REALTYPE fp214;
fp214 = inteval->oo2ze[vi] * src4[((hsi*15+6)*1+lsi)*1];
LIBINT2_REALTYPE fp216;
fp216 = inteval->WP_z[vi] * src1[((hsi*45+20)*1+lsi)*1];
LIBINT2_REALTYPE fp217;
fp217 = inteval->PA_z[vi] * src0[((hsi*45+20)*1+lsi)*1];
LIBINT2_REALTYPE fp215;
fp215 = fp217 + fp216;
LIBINT2_REALTYPE fp213;
fp213 = fp215 + fp214;
target[((hsi*63+35)*1+lsi)*1] = fp213;
LIBINT2_REALTYPE fp219;
fp219 = inteval->WP_z[vi] * src1[((hsi*45+19)*1+lsi)*1];
LIBINT2_REALTYPE fp220;
fp220 = inteval->PA_z[vi] * src0[((hsi*45+19)*1+lsi)*1];
LIBINT2_REALTYPE fp218;
fp218 = fp220 + fp219;
target[((hsi*63+34)*1+lsi)*1] = fp218;
LIBINT2_REALTYPE fp222;
fp222 = inteval->WP_z[vi] * src1[((hsi*45+18)*1+lsi)*1];
LIBINT2_REALTYPE fp223;
fp223 = inteval->PA_z[vi] * src0[((hsi*45+18)*1+lsi)*1];
LIBINT2_REALTYPE fp221;
fp221 = fp223 + fp222;
target[((hsi*63+33)*1+lsi)*1] = fp221;
LIBINT2_REALTYPE fp227;
fp227 = inteval->roz[vi] * src3[((hsi*30+11)*1+lsi)*1];
LIBINT2_REALTYPE fp226;
fp226 = src2[((hsi*30+11)*1+lsi)*1] - fp227;
LIBINT2_REALTYPE fp228;
fp228 = 3 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp225;
fp225 = fp228 * fp226;
LIBINT2_REALTYPE fp230;
fp230 = inteval->WP_y[vi] * src1[((hsi*45+20)*1+lsi)*1];
LIBINT2_REALTYPE fp231;
fp231 = inteval->PA_y[vi] * src0[((hsi*45+20)*1+lsi)*1];
LIBINT2_REALTYPE fp229;
fp229 = fp231 + fp230;
LIBINT2_REALTYPE fp224;
fp224 = fp229 + fp225;
target[((hsi*63+32)*1+lsi)*1] = fp224;
}
}
}
const int hsi = 0;
const int lsi = 0;
const int vi = 0;
/** Number of flops = 441 */
}

#ifdef __cplusplus
};
#endif
